#!/bin/sh

echo "[info] this is check_karate 20120530"
echo "[info] `date`"
echo "[info] kernel-version: \"`uname -a`\""

#
# Make sure not other process is writing to the device
#
if [ `ps | grep atmo | grep -v grep | wc -l` -gt 0 ]; then
  if [ -e /etc/init.d/atmolight ]; then
    exec /etc/init.d/atmolight stop 
    echo "[fail] atmolight daemon was still running!"
  else
    echo "[fail] Shut down the atmolight daemon first"
    exit
  fi;
fi;

#
# check for lsusb binary
#
if [ ! -x `which lsusb` ]; then
  echo "[fail] lsusb binary not found. please install usbutils"
  exit 
fi


DEV=`lsusb | grep 04d8`
if [ `echo $DEV | wc -c` -le 1 ]; then
  echo "[fail] KarateLight not Connected to USB"
  exit 
fi
echo "[pass] Found a KarateLight device (vendor-id==0x04d8)"

DEVM=`echo $DEV | cut -d":" -f 3 | cut -c 1-4`;
if [ $DEVM != "000a" ]; then
  echo "[fail] KarateLight not in cdc-acm mode"
  echo " perhaps the device is in bootload mode?"
  exit 
fi
echo "[pass] Found a KarateLight device (device-id==0x000a)"

if [ ! 1 -le `lsmod  | grep cdc | wc -l` ]; then
  echo "[fail] CDC-ACM Kernel Moduele not loadad"
  echo " try 'modprobe cdc-acm'"
  exit 
fi
echo "[pass] CDC-ACM Kernel-Module is loadad"

NODES="/dev/ttyACM0 /dev/ttyACM1"
for A in $NODES
do
  if [ -w $A ]; then
    echo "[info] device $A is writeable. Using it for further tests.."
    KRDEV=$A;
  fi
done

if [ `echo $KRDEV | wc -c` -eq 0 ]; then
  echo "[fail] no device-node found"
  exit 
fi

if [ ! -x `which karate-getinfo` ]; then
  echo "[fail] karate_getinfo binary not found"
  exit 
fi


KINFO=`karate-getinfo $KRDEV`;
KRINFORET=$?;

if [ $KRINFORET -ne 0 ]; then
  echo "[fail] running karate_getinfo failed"
  exit
fi

KRFW=`echo $KINFO | cut  -d" " -f 1`;
echo "[info] Firmware-Version is $KRFW"

KRBY=`echo $KINFO | cut  -d" " -f 2`;
KRCH=$(($KRBY * 8 / 12 / 3))

echo "[info] Device reports $KRCH Channels"
